@@ -1,9 +1,12 @@
+import sys
+sys.path.append('../mattlib')
+from mattlib.BaseAPI import BaseAPI
 from google.oauth2 import service_account
 import googleapiclient.discovery
 import json
 
-class BaseGoogleAPI:
-    def __init__(self, credentials_file, subject=None):
+class BaseGoogleAPI(BaseAPI):
+    def connect(self, credentials_file, subject=None):
        if credentials_file == None:
            raise Exception('Necessário arquivo .json com credenciais do clente')
        self.credentials = self.get_credentials(credentials_file, subject)
